=========================
Tidalstream Dummy Service
=========================

This is a dummy service that can be used for testing the installation of external plugins.

You probably don't have any use for this plugin as it does nothing....

License
--------

This project is licensed under the MIT License.
